@@ -24,10 +24,12 @@
 #' \item \code{band} - Bandwidth values for each covariate.
 #' \item \code{measures} - Goodness of fit statistics.
 #' \item \code{ENP} - Effective number of parameters.
+#' \item \code{mgwr_param_estimates} - MGWR parameter estimates.
 #' \item \code{qntls_mgwr_param_estimates} - Quantiles of MGWR parameter estimates.
 #' \item \code{descript_stats_mgwr_param_estimates} - Descriptive statistics of MGWR parameter estimates.
 #' \item \code{p_values} - P-values for the t tests on parameter significance.
 #' \item \code{t_critical} - Critical values for the t tests on parameter significance.
+#' \item \code{mgwr_se} - MGWR standard errors.
 #' \item \code{qntls_mgwr_se} - Quantiles of MGWR standard errors.
 #' \item \code{descript_stats_se} - Descriptive statistics of MGWR standard errors.
 #' \item \code{global_param_estimates} - Parameter estimates for the global model.
@@ -540,13 +542,17 @@ mgwnbr <- function(data, formula, weight=NULL, lat, long,
       h2 <- ax1+r*(bx1-ax1)
       res1 <- cv(h1, depy, indepx, fix)
       assign("s", s, envir=parent.frame())
-      assign("ai", ai, envir=parent.frame())
+      if (model!="gaussian"){ #release 2
+        assign("ai", ai, envir=parent.frame())
+      }#release 2
       assign("yhat", yhat, envir=parent.frame())
       assign("alphai", alphai, envir=parent.frame())
       CV1 <- res1[1]
       res2 <- cv(h2,depy,indepx,fix)
       assign("s", s, envir=parent.frame())
-      assign("ai", ai, envir=parent.frame())
+      if (model!="gaussian"){ #release 2
+        assign("ai", ai, envir=parent.frame())
+      } #release 2
       assign("yhat", yhat, envir=parent.frame())
       assign("alphai", alphai, envir=parent.frame())
       CV2 <- res2[1]
@@ -559,7 +565,9 @@ mgwnbr <- function(data, formula, weight=NULL, lat, long,
           CV1 <- CV2
           res2 <- cv(h2,depy,indepx,fix)
           assign("s", s, envir=parent.frame())
-          assign("ai", ai, envir=parent.frame())
+          if (model!="gaussian"){ #release 2
+            assign("ai", ai, envir=parent.frame())
+          } #release 2
           assign("yhat", yhat, envir=parent.frame())
           assign("alphai", alphai, envir=parent.frame())
           CV2 <- res2[1]
@@ -571,7 +579,9 @@ mgwnbr <- function(data, formula, weight=NULL, lat, long,
           CV2 <- CV1
           res1 <- cv(h1, depy, indepx, fix)
           assign("s", s, envir=parent.frame())
-          assign("ai", ai, envir=parent.frame())
+          if (model!="gaussian"){ #release 2
+            assign("ai", ai, envir=parent.frame())
+          } #release 2
           assign("yhat", yhat, envir=parent.frame())
           assign("alphai", alphai, envir=parent.frame())
           CV1 <- res1[1]
@@ -613,13 +623,17 @@ mgwnbr <- function(data, formula, weight=NULL, lat, long,
         h2 <- ax1+r*(bx1-ax1)
         res1 <- cv(h1, depy, indepx, fix)
         assign("s", s, envir=parent.frame())
-        assign("ai", ai, envir=parent.frame())
+        if (model!="gaussian"){ #release 2
+          assign("ai", ai, envir=parent.frame())
+        } #release 2
         assign("yhat", yhat, envir=parent.frame())
         assign("alphai", alphai, envir=parent.frame())
         CV1 <- res1[1]
         res2 <- cv(h2,depy,indepx,fix)
         assign("s", s, envir=parent.frame())
-        assign("ai", ai, envir=parent.frame())
+        if (model!="gaussian"){ #release 2
+          assign("ai", ai, envir=parent.frame())
+        } #release 2
         assign("yhat", yhat, envir=parent.frame())
         assign("alphai", alphai, envir=parent.frame())
         CV2 <- res2[1]
@@ -632,7 +646,9 @@ mgwnbr <- function(data, formula, weight=NULL, lat, long,
             CV1 <- CV2
             res2 <- cv(h2,depy,indepx,fix)
             assign("s", s, envir=parent.frame())
-            assign("ai", ai, envir=parent.frame())
+            if (model!="gaussian"){ #release 2
+              assign("ai", ai, envir=parent.frame())
+            } #release 2
             assign("yhat", yhat, envir=parent.frame())
             assign("alphai", alphai, envir=parent.frame())
             CV2 <- res2[1]
@@ -644,7 +660,9 @@ mgwnbr <- function(data, formula, weight=NULL, lat, long,
             CV2 <- CV1
             res1 <- cv(h1, depy, indepx, fix)
             assign("s", s, envir=parent.frame())
-            assign("ai", ai, envir=parent.frame())
+            if (model!="gaussian"){ #release 2
+              assign("ai", ai, envir=parent.frame())
+            } #release 2
             assign("yhat", yhat, envir=parent.frame())
             assign("alphai", alphai, envir=parent.frame())
             CV1 <- res1[1]
@@ -1267,6 +1285,14 @@ mgwnbr <- function(data, formula, weight=NULL, lat, long,
   qntl <- rbind(round(qntl, 6), IQR=round(IQR, 6))
   descriptb <- rbind(apply(beta2, 2, mean), apply(beta2, 2, min), apply(beta2, 2, max))
   rownames(descriptb) <- c('Mean', 'Min', 'Max')
+  if (model=='negbin'){ #release 2
+    colnames(beta2) <- c('Intercept', XVAR, 'alpha')#release 2
+  } #release 2
+  else{ #release 2
+    colnames(beta2) <- c('Intercept', XVAR) #release 2
+  } #release 2
+  output <- append(output, list(as.data.frame(beta2))) #release 2
+  names(output)[length(output)] <- "mgwr_param_estimates" #release 2
   if (model=='negbin'){
     colnames(qntl) <- c('Intercept', XVAR, 'alpha')
   }
@@ -1303,6 +1329,14 @@ mgwnbr <- function(data, formula, weight=NULL, lat, long,
   header <- append(header, "t-Critical")
   output <- append(output, list(t_critical))
   names(output)[length(output)] <- "t_critical"
+  if (model=='negbin'){ #release 2
+    colnames(stdbeta2) <- c('Intercept', XVAR, 'alpha')#release 2
+  } #release 2
+  else{ #release 2
+    colnames(stdbeta2) <- c('Intercept', XVAR) #release 2
+  } #release 2
+  output <- append(output, list(as.data.frame(stdbeta2))) #release 2
+  names(output)[length(output)] <- "mgwr_se" #release 2
   if (model=='negbin'){
     colnames(qntls) <- c('Intercept', XVAR, 'alpha')
   }
